=============================
 Requirements-Builder v0.2.6
=============================

Requirements-Builder v0.2.6 was released on July 13, 2017.

About
-----

Build requirements files from setup.py requirements.

Bug fixes
---------

- Fixes fatal error if setup() is called under 'if __name__ == "__main__":'

Installation
------------

   $ pip install requirements-builder==0.2.6

Documentation
-------------

   http://requirements-builder.readthedocs.io/

Happy hacking and thanks for flying Requirements-Builder.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/requirements-builder
|   URL: http://inveniosoftware.org
